@@ -12,7 +12,7 @@ def setup_terrier(file_path):
     if not os.path.isfile(os.path.join(file_path,"terrier-assemblies-5.1-jar-with-dependencies.jar")):
         print('JAR file not found, downloading')
         url = 'https://repo.maven.apache.org/maven2/org/terrier/terrier-assemblies/5.1/terrier-assemblies-5.1-jar-with-dependencies.jar'
-        wget.download(url, '.')
+        wget.download(url, file_path)
     # import jnius_config
     # jnius_config.add_classpath("./terrier-assemblies-5.1-jar-with-dependencies.jar")
     # from jnius import autoclass, cast
